| Title: | Random Elven Names |
| Version: | 0.1.0 |
| Description: | Generate random elven names, that are unique and politically correct. This can be used to anonymize data, for example. This is based on the algorithm proposed on https://web.archive.org/web/20210412140219/https://www.angelfire.com/rpg2/vortexshadow/names.html. |
| License: | MIT + file LICENSE |
| URL: | https://github.com/ulysg/randelves |
| BugReports: | https://github.com/ulysg/randelves/issues |
| Imports: | cli, dplyr, glue |
| Suggests: | testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| Encoding: | UTF-8 |
| RoxygenNote: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-07-22 14:09:17 UTC; ulys |
| Author: | Ulysse Geinoz [aut, cre, cph] |
| Maintainer: | Ulysse Geinoz <compte@ulys.ch> |
| Repository: | CRAN |
| Date/Publication: | 2026-07-30 19:30:08 UTC |
Return a list of unique random elven names
Description
Return a list of unique random elven names
Usage
random_elves(number, short = FALSE)
Arguments
number |
the number of names to generate, should be less than 20'000 |
short |
whether the names should be short or of a random length |
Value
a vector of elven names
Examples
random_elves(1, FALSE)
random_elves(5000, TRUE)